"""Handle processes."""

import subprocess

from rwx import txt


def get_tuples_args(*tuples: tuple[str]) -> list[str]:
    """Turn arguments tuples into an arguments list."""
    args: list[str] = []
    for item in tuples:
        if type(item) is tuple:
            args.extend(item)
        else:
            args.append(item)
    return args


def run(*tuples: tuple[str]) -> subprocess.CompletedProcess:
    """Run from a list of arguments tuples."""
    return subprocess.run(
        get_tuples_args(tuples), capture_output=False, check=True
    )


def run_line(*tuples: tuple[str], charset: str = txt.CHARSET) -> str:
    """Run and return output line."""
    lines = run_lines(*get_tuples_args(tuples), charset=charset)
    return lines[0]


def run_lines(*tuples: tuple[str], charset: str = txt.CHARSET) -> list[str]:
    """Run and return output lines."""
    process = subprocess.run(
        get_tuples_args(tuples), capture_output=True, check=True
    )
    string = process.stdout.decode(charset)
    return string.rstrip().splitlines()
